@@ -2,6 +2,8 @@ from dataclasses import dataclass
 from typing import List
 
 from dataclasses_json import dataclass_json
+
+from .fields import default
 from .map_detail import MapDetail
 from .user_detail import UserDetail
 
@@ -9,6 +11,6 @@ from .user_detail import UserDetail
 @dataclass_json
 @dataclass
 class SearchResponse:
-    docs: List[MapDetail]
-    redirect: str
-    user: UserDetail
+    docs: List[MapDetail] = default()
+    redirect: str = default()
+    user: UserDetail = default()
